==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/da/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Mere information",

    "audit_help" => "Afkrydsning af dette felt vil redigere aktivposten så den afspejler denne nye placering. Ingen markering angiver blot, placeringen i revisionsloggen.<br><br>Bemærk, at hvis dette aktiv er tjekkes ud, det vil ikke ændre placeringen af personen, aktivet eller placeringen, det er tjekket ud til.",

    'assets' => 'Aktiver er elementer sporet efter serienummer eller aktiv tag. De har tendens til at være elementer af højere værdi, hvor identificering af en bestemt genstand betyder noget.',

    'categories' => 'Aktiv-kategorier hjælper dig med at organisere dine enheder. Eksempler på kategorier kunne være &quot;Stationære coputere&quot;, &quot;Bærbare&quot;, &quot;Mobiltelefoner&quot;, &quot;Tabletter&quot; osv., men du kan bruge aktiver kategorier på en hvilken som helst måde som giver mening for dig.',

    'accessories' => 'Tilbehør er alt du udleverer til brugere men som ikke har et serienummer (eller som du er ligeglad med følge præcist). For eksempel, computermus eller tastaturer.',

    'companies'     => 'Virksomheder kan bruges som et simpelt id-felt, eller kan bruges til at begrænse synligheden af aktiver, brugere osv, hvis fuld virksomhedssupport er aktiveret i dine Admin-indstillinger.',

    'components'    => 'Komponenter er elementer, der er en del af et aktiv, for eksempel HDD, RAM osv.',

    'consumables'   => 'Forbrugsvarer er noget der købes og bruges op over tid. For eksempel printer blæk eller kopimaskine papir.',

    'depreciations' => 'Du kan sætte aktivafskrivninger til at afskrive aktiver som lineære afskrivninger.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/da/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Mere information',

    'audit_help' => 'Afkrydsning af dette felt vil redigere aktivposten så den afspejler denne nye placering. Ingen markering angiver blot, placeringen i revisionsloggen.<br><br>Bemærk, at hvis dette aktiv er tjekkes ud, det vil ikke ændre placeringen af personen, aktivet eller placeringen, det er tjekket ud til.',

    'assets' => 'Aktiver er elementer sporet efter serienummer eller aktiv tag. De har tendens til at være elementer af højere værdi, hvor identificering af en bestemt genstand betyder noget.',

    'categories' => 'Aktiv-kategorier hjælper dig med at organisere dine enheder. Eksempler på kategorier kunne være &quot;Stationære coputere&quot;, &quot;Bærbare&quot;, &quot;Mobiltelefoner&quot;, &quot;Tabletter&quot; osv., men du kan bruge aktiver kategorier på en hvilken som helst måde som giver mening for dig.',

    'accessories' => 'Tilbehør er alt du udleverer til brugere men som ikke har et serienummer (eller som du er ligeglad med følge præcist). For eksempel, computermus eller tastaturer.',

    'companies'     => 'Virksomheder kan bruges som et simpelt id-felt, eller kan bruges til at begrænse synligheden af aktiver, brugere osv, hvis fuld virksomhedssupport er aktiveret i dine Admin-indstillinger.',

    'components'    => 'Komponenter er elementer, der er en del af et aktiv, for eksempel HDD, RAM osv.',

    'consumables'   => 'Forbrugsvarer er noget der købes og bruges op over tid. For eksempel printer blæk eller kopimaskine papir.',

    'depreciations' => 'Du kan sætte aktivafskrivninger til at afskrive aktiver som lineære afskrivninger.',

];
